@@ -1,3 +1,3 @@
-pub(crate) mod error;
+pub mod error;
 pub mod models;
 pub(crate) mod ops;
